dt_save: Save to .pdf, .html or .docx

Description Usage Arguments Value

View source: R/save.R

Description

dt_save export a rendered dt object in the corresponding file format

Usage

1
dt_save(x, file, path = NULL)

Arguments

x

A dt object rendered by one of those functions dt_to_html(), dt_to_latex() or dt_to_flextable()

file

A file name without extension file specified.

path

A path to directory where file should be save. If NULL (default) file will be save in the current working directory.

Value

pdf, html or docx file


jrmie/dtr documentation built on April 22, 2020, 10:32 p.m.

Related to dt_save in jrmie/dtr...