Description Usage Arguments Value
dt_save export a rendered dt object in the corresponding file format
1 |
x |
A dt object rendered by one of those functions |
file |
A file name without extension file specified. |
path |
A path to directory where file should be save. If NULL (default) file will be save in the current working directory. |
pdf, html or docx file
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.