Description Create Inspect Rendering to report Export
The purpose of the package is to quickly get a numerical description of a set of variables as well a statistical comparison between groups of interest. This is an usual task in medical researches as clinical trials or epidemiological studies to better know the population, but reporting it may become tedious.
The main function dt_create takes a dataset, a
grouping variable and additionnal arguments to personnalized the output
(e.g. number of digits, statistical comparisons, overall description).
The function return a dt object.
Original descriptive table as characters data frame can be extract from the dt object. Details of each statistical test can be extract ...
dt objects from dt_create can be pass
to
dt_to_html or dt_to_latex to
get the corresponding HTML or LaTeX code generated by the
kableExtra package
dt_to_flextable to get the corresponding flextable object
generated by the flextable
package
print method to get an ASCII version of the
table
Output returned by this 3 functions can be directly use in Rmarkdown documents
Instead of use rendering functions directly in Rmarkdown
documents, tables outputed from dt_to_html,
dt_to_latex or dt_to_flextable can be save as
.html, .pdf or .docx files with the
dt_save function
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.